# PyTools
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro] (https://www.python.pro.br/)

[![Build Status](https://app.travis-ci.com/RoberthGuimaro/PyTools.svg?branch=main)](https://app.travis-ci.com/RoberthGuimaro/PyTools)

Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requeriments-dev.txt
```

Para conferir qualidade do código:
```console
flake8
```